#ifndef PV6_VID_TEST_SDK_H
#define PV6_VID_TEST_SDK_H

#ifdef _PV6VIDTESTDLL
#define PV6_VID_TEST_API extern "C"__declspec(dllexport)
#else
#define PV6_VID_TEST_API extern "C"__declspec(dllimport)
#endif

// wFrameType Definition
#define	FRAMETYPE_NOSIGNAL					0x0001
#define FRAMETYPE_ALARM						0x0002
#define FRAMETYPE_MOTION					0x0004
#define FRAMETYPE_PTZCTRL					0x0008
#define FRAMETYPE_SUBSTREAM				0x0010
#define FRAMETYPE_AUDIO						0x0020
#define FRAMETYPE_AUDIOSUPPORT				0x0040
#define FRAMETYPE_VOICESUPPORT            0x0080
#define FRAMETYPE_DUPLICATE					0x0100
#define FRAMETYPE_DROP						0x0200
#define	FRAMETYPE_BACKGROUND				0x0400
#define FRAMETYPE_RECORDING					0x0800
#define FRAMETYPE_BREAKABLE					0x1000
#define FRAMETYPE_LEADING					0x2000
#define FRAMETYPE_PIFRAME					0x4000
#define FRAMETYPE_KEYFRAME					0x8000

typedef enum
{ 
   StatusFileCorrupt          = -16,
   StatusFileHadOpen          = -15,
   StatusEndOfFrame           = -14,
   StatusFileOpenFail         = -13,
   StatusFail                 = -12,    
   StatusInvalidPosition      = -11,   //
   StatusStartOfStream        = -10,   //
   StatusEndOfStream          = -9,    //
   StatusInvalidParameter     = -8,    //
   StatusNoVIDFileOpen        = -7,    //
   StatusInvalidVIDFile       = -6,    //
   StatusFileNotFound         = -5,    // 
   StatusHaveNotReadGOP       = -4,    //
   StatusNoMemError           = -3,    // Not enough memory for the operation. 
   StatusNullPointer          = -1,    // Null pointer error. 
   StatusSizeError            = -2,    // Wrong value of data size. 
   StatusNoError              = 0,     // No error occur.
   StatusNotImplement         = 1,     // Function is not implement.
}Adv_Status;

#pragma pack(1)
struct	FRAMEINFO
{
   int			nInfoSize;
   COLORREF	clrOsd;		// 0xSSBBGGRR : SS=FontSize
   time_t	tmTime;
   short		timezone;
   short		dstflag;
   WORD		wMilliSec;
   WORD		wChannelNo;
   WORD		wAuthority;
   WORD		wFrameType;
   WORD		wWidth;
   WORD		wHeight;
   DWORD		dwFrameSize;
   DWORD		dwFourCC;
   char		szName[25];
   WORD		nExtraSize;
   char		chReserved[ 1 ];
};
typedef struct	FRAMEINFO * PFRAMEINFO;
#define SIZEOF_FRAMEINFO(p) (p->nInfoSize+p->nExtraSize)


struct AUDIOINFO
{
   WORD	wInfoSize;
   WORD	wChannelNo;
   time_t  tmTime;
   DWORD	dwDataSize;
   WORD    wMilliSec;	
};
typedef AUDIOINFO* PAUDIOINFO;

typedef LONGLONG Adv_File_Handle; 

//add by ren.xi [2014-09-18]
#define CONTTYPE_TEXT						0x0001
#define CONTTYPE_GPS						0x0002
#define CONTTYPE_MASK						0x0003
#define CONTTYPE_IVSINFO				0x0004

struct	EXTRACONTHDR
{
   BYTE	byContextType;
   DWORD dwId;
   WORD	wContextSize;
};
typedef struct	EXTRACONTHDR * PEXTRACONTHDR;

struct	EXTRACONTEXT
{
   EXTRACONTHDR	Hdr;
   char			szContext[1];
};
typedef struct	EXTRACONTEXT * PEXTRACONTEXT;

#define SIZEOF_EXTRADATA(p)   (sizeof(p->Hdr)+p->Hdr.wContextSize)

enum ExtraData_Type{IVS, POS, LPR};
struct ExtraData_Text
{
   struct String
   {
      ExtraData_Type wTag;
      COLORREF color;
      BYTE fontSize;       // font size under 320*240
      BYTE drawMode;       // 0 - normal, 1 - XOR
      BYTE xPos;           // Unit: 1/240 width of video frame window
      BYTE yPos;           // Unit: 1/240 height of video frame window
      WORD wLen;           // The length includes null char.
      char content[1];
   };

   BYTE nStrCnt;
   String str[1];
};


typedef enum {
   FRAMETYPE_I  = 0,
   FRAMETYPE_P  = 1,
   FRAMETYPE_Others = 3,
} Frame_Type;

struct FRAMERESOLUTION
{
   int width;
   int height;
};

struct VIDINFODETAIL
{
   unsigned long    lTotalFrameCount; 
   unsigned long    lTotalDataSize;   //total size of stream data
   unsigned long    lTotalOSDSize;  
   unsigned long    lGOPCount;   
   unsigned int*    pGOPSize;    //GOPSize of each GOP, һGopж֡
   unsigned long*   pGOPFrameSize; //dataSize of each GOP, һGopݴСÿ֡frameinfoĴС+OSDĴС+DataĴС 
   BYTE**           pFrameInfo;  //frameInfo of each frame
   char**           pOSDInfo; //osd of each frame
   Frame_Type*      pFrameType;
   FRAMERESOLUTION* pFrameResolutionFromData;  

   unsigned int     averageGOPSize;  // lTotalFrameCount/GOPCount  //ÿGopƽж֡
   unsigned int     countOfGOPSizeRange; //count of GOPSize Range  //жGop size
   unsigned int*    pGOPSizeRange;      // ͬGop size б
   unsigned int*    pGOPSizeCount;  //each GOPSize count in range  //ÿGop sizeֱжٸ

   unsigned int     averageFrameRate;  // (lTotalFrameCount/totalTime) 
   //unsigned int     countOfFrameRateRange;
   //unsigned int*    pFrameRateRange;
   //unsigned int*    pFrameRateCount;


   VIDINFODETAIL()
   {
      lTotalFrameCount = 0;
      lTotalDataSize = 0;
      lTotalOSDSize = 0;
      lGOPCount = 0;
      pGOPSize = NULL;
      pGOPFrameSize = NULL;
      pFrameInfo = NULL;
      pOSDInfo = NULL;
      pFrameType = NULL;
      pFrameResolutionFromData = NULL;

      averageGOPSize = 0;
      countOfGOPSizeRange = 0;
      pGOPSizeRange = NULL;
      pGOPSizeCount = NULL;
      
      averageFrameRate = 0;
      //countOfFrameRateRange = 0;
      //pFrameRateRange = NULL;
      //pFrameRateCount = NULL;
   }
   ~VIDINFODETAIL()
   {
      lTotalFrameCount = 0;
      lTotalDataSize = 0;
      lTotalOSDSize = 0;
      lGOPCount = 0;
      pGOPSize = NULL;
      pGOPFrameSize = NULL;
      pFrameInfo = NULL;
      pOSDInfo = NULL;
      pFrameType = NULL;
      pFrameResolutionFromData = NULL;

      averageGOPSize = 0;
      countOfGOPSizeRange = 0;
      pGOPSizeRange = NULL;
      pGOPSizeCount = NULL;

      averageFrameRate = 0;
      //countOfFrameRateRange = 0;
      //pFrameRateRange = NULL;
      //pFrameRateCount = NULL;
   }
};

typedef VIDINFODETAIL* PVIDINFODETAIL;
//~ren.xi


/******************************************************************************
* Function
		The function open a specfic vid or aud file.
******************************************************************************/
PV6_VID_TEST_API Adv_File_Handle WINAPI AdvSDK_OpenFile( LPCTSTR lpszFileNames );

PV6_VID_TEST_API Adv_Status WINAPI AdvSDK_CloseFile( Adv_File_Handle hFileHandle );

PV6_VID_TEST_API LONG WINAPI AdvSDK_GetFrameNumber( Adv_File_Handle hFileHandle );

PV6_VID_TEST_API Adv_Status WINAPI AdvSDK_ReadDataSize( Adv_File_Handle hFileHandle, long lPos, long* lpSize );

PV6_VID_TEST_API Adv_Status WINAPI AdvSDK_ReadDataInfo( Adv_File_Handle hFileHandle, long lPos, LPBYTE lpDataInfo, long lSize );

PV6_VID_TEST_API Adv_Status WINAPI AdvSDK_ReadData( Adv_File_Handle hFileHandle, LPBYTE lpData, BOOL bAudio );

PV6_VID_TEST_API Adv_Status WINAPI AdvSDK_GetFormat( Adv_File_Handle hFileHandle, LPVOID lpFormat, LPDWORD lpdwFormatSize );

PV6_VID_TEST_API Adv_Status WINAPI AdvSDK_GetFileTime( Adv_File_Handle hFileHandle, time_t* ptmStart, time_t* ptmEnd );

//add by ren.xi [2014-09-18]
PV6_VID_TEST_API Adv_Status WINAPI AdvSDK_GetVidInfoDetail( LPCTSTR lpszFileNames , PVIDINFODETAIL pVidInfoDetail );

PV6_VID_TEST_API Adv_Status WINAPI AdvSDK_FreeVidInfoDetail( PVIDINFODETAIL pVidInfoDetail );

PV6_VID_TEST_API Adv_Status WINAPI AdvSDK_GetFrameType( Adv_File_Handle hFileHandle, LPBYTE lpData, DWORD dwDataSize, Frame_Type& frameType );

PV6_VID_TEST_API Adv_Status WINAPI AdvSDK_GetFrameResolution( Adv_File_Handle hFileHandle, LPBYTE lpData, DWORD dwDataSize, int& width, int& height );
// auto link
#if !defined( VIDREADER_EXPORTS )
#pragma comment ( lib, "PV6VIDTest.lib" )
#endif // VIDREADER_EXPORTS

//~ren.xi
#endif // PV6_VID_TEST_SDK_H


